@@ -20,14 +20,13 @@
 Configuration options registration and useful routines.
 """
 
-import itertools
 import json
 
 from keystoneauth1 import loading
 from oslo_config import cfg
 from oslo_log import log
 from oslo_middleware import cors
-from oslo_policy import opts
+from oslo_service import _options as service_opts
 from osprofiler import opts as profiler
 
 from mistral import version
@@ -198,22 +197,19 @@ rpc_impl_opt = cfg.StrOpt(
     'rpc_implementation',
     default='oslo',
     choices=['oslo', 'kombu'],
+    deprecated_for_removal=True,
+    deprecated_reason='Kombu driver is deprecated and will be removed '
+                      'in the F release cycle',
     help=_('Specifies RPC implementation for RPC client and server. '
            'Support of kombu driver is experimental.')
 )
 
-# TODO(ddeja): This config option is a part of oslo RPCClient
-# It would be the best to not register it twice, rather use RPCClient somehow
-rpc_response_timeout_opt = cfg.IntOpt(
-    'rpc_response_timeout',
-    default=60,
-    help=_('Seconds to wait for a response from a call.')
-)
-
 oslo_rpc_executor = cfg.StrOpt(
     'oslo_rpc_executor',
-    default='eventlet',
-    choices=['eventlet', 'blocking', 'threading'],
+    default='threading',
+    choices=['eventlet', 'threading'],
+    deprecated_for_removal=True,
+    deprecated_reason='This option is going to be removed from oslo.messaging',
     help=_('Executor type used by Oslo Messaging framework. Defines how '
            'Oslo Messaging based RPC subsystem processes incoming calls.')
 )
@@ -543,7 +539,7 @@ execution_expiration_policy_opts = [
         default=[],
         help='The states that the expiration policy will filter '
              'out and will not delete.'
-             'Valid values are, [{}]'.format(states.TERMINAL_STATES)
+             'Valid values are, [{}]'.format(sorted(states.TERMINAL_STATES))
     )
 ]
 
@@ -640,6 +636,8 @@ coordination_opts = [
     cfg.StrOpt(
         'backend_url',
         secret=True,
+        deprecated_for_removal=True,
+        deprecated_reason='Coordination will be removed from mistral code',
         help=_('The backend URL to be used for coordination')
     ),
     cfg.FloatOpt(
@@ -826,9 +824,9 @@ CONF.register_opt(auth_type_opt)
 CONF.register_opt(scheduler_type_opt)
 CONF.register_opt(js_impl_opt)
 CONF.register_opt(rpc_impl_opt)
-CONF.register_opt(rpc_response_timeout_opt)
 CONF.register_opt(oslo_rpc_executor)
 CONF.register_opt(expiration_token_duration)
+CONF.register_opts(service_opts.service_opts)
 
 CONF.register_opts(action_providers_opts, group=ACTION_PROVIDERS_GROUP)
 CONF.register_opts(
@@ -865,19 +863,15 @@ CLI_OPTS = [
     launch_opt
 ]
 
-default_group_opts = itertools.chain(
-    CLI_OPTS,
-    [
-        wf_trace_log_name_opt,
-        auth_type_opt,
-        scheduler_type_opt,
-        js_impl_opt,
-        rpc_impl_opt,
-        rpc_response_timeout_opt,
-        oslo_rpc_executor,
-        expiration_token_duration
-    ]
-)
+default_group_opts = CLI_OPTS + [
+    wf_trace_log_name_opt,
+    auth_type_opt,
+    scheduler_type_opt,
+    js_impl_opt,
+    rpc_impl_opt,
+    oslo_rpc_executor,
+    expiration_token_duration
+]
 
 
 _DEFAULT_LOG_LEVELS = [
@@ -934,10 +928,6 @@ def parse_args(args=None, usage=None, default_config_files=None):
 def set_config_defaults():
     """This method updates all configuration default values."""
     set_cors_middleware_defaults()
-    # TODO(gmann): Remove setting the default value of config policy_file
-    # once oslo_policy change the default value to 'policy.yaml'.
-    # https://github.com/openstack/oslo.policy/blob/a626ad12fe5a3abd49d70e3e5b95589d279ab578/oslo_policy/opts.py#L49
-    opts.set_defaults(CONF, 'policy.yaml')
 
 
 def set_cors_middleware_defaults():
